Zoe - Container-based Analytics as a Service
============================================

Zoe provides a simple way to provision data analytics clusters and
workflows using container-based (Docker) virtualization. The guiding
principles are:

-  ease of use: data scientists know about data and applications,
   systems and resource constraints should be kept out of the way
-  ease of administration: we have a strong background in systems and
   network administration, so we put all effort possible to make Zoe
   ease to install and maintain
-  use well-known technologies: we try hard not to reinvent the wheel,
   we use Python, ZeroMQ, Docker and the Apache Web Server
-  a clear roadmap: our short and long-term objectives should always be
   clear and well defined
-  openness: the source code is open: clone, modify, discuss, test and
   contribute, you are welcome!

Resources:

-  Documentation: http://zoe-analytics.readthedocs.org/
-  Docker images:
   https://github.com/DistributedSystemsGroup/zoe-docker-images

|Documentation Status| |Requirements Status|

Zoe is licensed under the terms of the Apache 2.0 license.

.. |Documentation Status| image:: https://readthedocs.org/projects/zoe-analytics/badge/?version=latest
   :target: https://readthedocs.org/projects/zoe-analytics/?badge=latest
.. |Requirements Status| image:: https://requires.io/github/DistributedSystemsGroup/zoe/requirements.svg?branch=master
   :target: https://requires.io/github/DistributedSystemsGroup/zoe/requirements/?branch=master
